# Models

Dataclasses für Models.

::: questra_automation.models.ApplyPolicy
    options:
      show_source: false
      heading_level: 2

::: questra_automation.models.AutomationBuildStatus
    options:
      show_source: false
      heading_level: 2

::: questra_automation.models.AutomationExecutionDomainStatus
    options:
      show_source: false
      heading_level: 2

::: questra_automation.models.AutomationExecutionStatus
    options:
      show_source: false
      heading_level: 2

::: questra_automation.models.AutomationInitiatorType
    options:
      show_source: false
      heading_level: 2

::: questra_automation.models.ExecutionInitiator
    options:
      show_source: false
      heading_level: 2

::: questra_automation.models.RepositoryAuthenticationMethod
    options:
      show_source: false
      heading_level: 2

::: questra_automation.models.SortEnumType
    options:
      show_source: false
      heading_level: 2

::: questra_automation.models.AutomationArgumentDefinition
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.AutomationArgumentInstance
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.AutomationBuildError
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.KeyValuePair
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.PageInfo
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ServiceInfo
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.WorkspaceView
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.AutomationView
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.AutomationExecutionView
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.RepositoryView
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ScheduleView
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ScheduledExecutionView
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ErrorCodeView
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.AutomationsEdge
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.AutomationsConnection
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ExecutionsEdge
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ExecutionsConnection
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.RepositoriesEdge
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.RepositoriesConnection
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.SchedulesEdge
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.SchedulesConnection
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ScheduledExecutionsEdge
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ScheduledExecutionsConnection
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ErrorCodesEdge
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ErrorCodesConnection
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.WorkspacesEdge
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.WorkspacesConnection
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.ExecutePayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.CreateRepositoryPayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.UpdateRepositoryPayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.DeleteRepositoryPayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.RenewRepositorySshKeyPayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.CreateSchedulePayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.UpdateSchedulePayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.DeleteSchedulePayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.CreateWorkspacePayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.UpdateWorkspacePayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.DeleteWorkspacePayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_automation.models.SynchronizeWorkspacePayload
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true
